"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var yargs = require("yargs");
var assign = require("deep-assign");
var command_list_1 = require("./command-list");
var config_1 = require("./config");
var option_1 = require("./option");
function cli(pkg) {
    var configFilePath = path.join(process.cwd(), '.frcli.json');
    var cli = yargs.usage('Usage: frp <command> [options]');
    Object.keys(command_list_1.COMMAND_LIST).forEach(function (name) {
        var commandConf = command_list_1.COMMAND_LIST[name];
        cli.command(commandConf.command, commandConf.description, function (yg) { return yg.options(command_list_1.COMMAND_LIST[name].options); }, function (argv) {
            var options = assign({}, option_1.DEFAULT_OPTION);
            Object.keys(command_list_1.COMMAND_LIST[name].options).forEach(function (key) {
                options[key] = argv[key];
            });
            if (options.environment === 'prod' || options.environment === 'production' || options.production === true) {
                options.production = true;
                options.environment = 'prod';
            }
            if (options.production) {
                options.extractCss = true;
                options.sourcemaps = false;
            }
            var localConfig = {};
            if (name !== 'init') {
                if (!fs.existsSync(configFilePath)) {
                    throw new Error('Not found .frcli.json');
                }
                localConfig = require(configFilePath);
            }
            var config = assign({}, config_1.DEFAULT_CONFIG, localConfig);
            config.package = pkg;
            config.app.outDir = options['outputPath'] || config.app.outDir;
            command_list_1.COMMAND_LIST[name].action(config, options);
        });
    });
    return cli.help()
        .alias('help', 'h')
        .version()
        .demandCommand(1, 'Required command')
        .argv;
}
exports.cli = cli;
;
