'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var build_1 = require("./commands/build");
var generate_1 = require("./commands/generate");
var init_1 = require("./commands/init");
var serve_1 = require("./commands/serve");
var test_1 = require("./commands/test");
exports.COMMAND_LIST = {
    build: {
        command: 'build [options]',
        action: build_1.build,
        description: 'HTML/JS/CSSをビルド',
        options: {
            environment: {
                alias: 'e',
                describe: '使用する環境名',
                default: 'dev',
                type: 'string'
            },
            outputPath: {
                alias: 'op',
                describe: '出力先ディレクトリ',
                default: 'dist',
                type: 'string'
            },
            sourcemaps: {
                alias: 's',
                describe: 'ソースマップの書き出し',
                default: true,
                type: 'boolean'
            },
            verbose: {
                alias: 'v',
                describe: '詳細ログ表示',
                default: false,
                type: 'boolean'
            },
            extractCss: {
                alias: 'ec',
                describe: 'CSSをファイルとして書き出し',
                type: 'boolean'
            },
            production: {
                alias: 'p',
                describe: '本番用コード出力',
                default: false,
                type: 'boolean'
            },
            analyze: {
                alias: 'a',
                describe: 'バンドルされているファイルのマップを表示',
                default: false,
                type: 'boolean'
            },
            fix: {
                alias: 'f',
                describe: '軽微なLintエラーを自動修正',
                default: false,
                type: 'boolean'
            },
            tsConfig: {
                alias: 't',
                describe: 'tsconfigのパス',
                default: 'tsconfig.json',
                type: 'string'
            }
        }
    },
    /*****************************************************/
    serve: {
        command: 'serve [options]',
        action: serve_1.serve,
        description: '開発用サーバー起動',
        options: {
            environment: {
                alias: 'e',
                describe: '使用する環境名',
                default: 'dev',
                type: 'string'
            },
            outputPath: {
                alias: 'op',
                describe: '出力先ディレクトリ',
                type: 'string'
            },
            sourcemaps: {
                alias: 's',
                describe: 'ソースマップの書き出し',
                type: 'boolean'
            },
            verbose: {
                alias: 'v',
                describe: '詳細ログ表示',
                type: 'boolean'
            },
            extractCss: {
                alias: 'c',
                describe: 'CSSをファイルとして書き出し',
                type: 'boolean'
            },
            port: {
                describe: 'ポート番号',
                default: 4200,
                type: 'number'
            },
            open: {
                alias: 'o',
                describe: '実行時にブラウザを開く',
                default: false,
                type: 'boolean'
            },
            liveReload: {
                alias: 'l',
                describe: 'ファイル変更時に自動更新',
                default: true,
                type: 'boolean'
            },
            production: {
                alias: 'p',
                describe: '本番用コード出力',
                default: false,
                type: 'boolean'
            },
            analyze: {
                alias: 'a',
                describe: 'バンドルされているファイルのマップを表示',
                default: false,
                type: 'boolean'
            },
            fallback: {
                alias: 'f',
                describe: 'すべてのアクセスをindexにfallback',
                default: false,
                type: 'boolean'
            },
            write: {
                alias: 'w',
                describe: '実ファイルを出力',
                default: false,
                type: 'boolean'
            },
            fix: {
                alias: 'f',
                describe: '軽微なLintエラーを自動修正',
                default: false,
                type: 'boolean'
            },
            tsConfig: {
                alias: 't',
                describe: 'tsconfigのパス',
                default: 'tsconfig.json',
                type: 'string'
            },
            useIp: {
                alias: 'i',
                describe: 'ローカルIPでアクセス',
                default: false,
                type: 'boolean'
            },
            ssl: {
                describe: 'https接続',
                default: false,
                type: 'boolean'
            }
        }
    },
    /*****************************************************/
    generate: {
        command: 'generate [options]',
        action: generate_1.generate,
        description: 'テンプレートからファイルを生成',
        options: {}
    },
    /*****************************************************/
    init: {
        command: 'init [options]',
        action: init_1.init,
        description: 'プロジェクトの雛形を生成',
        options: {
            skipInstall: {
                alias: 's',
                describe: 'npm installの実行をスキップ',
                type: 'boolean',
                default: false
            },
            path: {
                alias: 'p',
                describe: 'テンプレートディレクトリ',
                type: 'string',
                default: null
            }
        }
    },
    /*****************************************************/
    test: {
        command: 'test [options]',
        action: test_1.test,
        description: 'テストを実行',
        options: {
            confFile: {
                alias: 'c',
                describe: 'karma.configパス',
                type: 'string'
            },
            port: {
                describe: 'ポート番号',
                default: 9000,
                type: 'number'
            },
            watch: {
                alias: 'w',
                describe: 'Watch状態にする',
                type: 'boolean'
            },
            environment: {
                alias: 'e',
                describe: '使用する環境名',
                type: 'string'
            },
            files: {
                alias: 'f',
                describe: 'テスト対象のファイル',
                type: 'string'
            },
            verbose: {
                alias: 'v',
                describe: '詳細ログ表示',
                default: false,
                type: 'boolean'
            }
        }
    }
};
