'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs-extra");
var path = require("path");
var chalk_1 = require("chalk");
var handlebars_1 = require("../handlebars/handlebars");
var glob = require("glob");
var inquirer = require("inquirer");
function generateConfigure(config) {
    return inquirer.prompt([{
            type: 'list',
            name: 'type',
            message: 'choose generate file type',
            choices: config.generate.types
        }, {
            type: 'input',
            name: 'name',
            message: 'Input file name',
            validate: function (answer) {
                return (!!answer);
            }
        }]);
}
exports.generateConfigure = generateConfigure;
function generate(config, option) {
    generateConfigure(config).then(function (answers) {
        answers.scriptType = config.app.scriptType || 'js';
        answers.dir = path.dirname(answers.name);
        answers.name = path.basename(answers.name);
        var templatePath = config.generate.templates[answers.type];
        if (!templatePath) {
            throw new Error("Undefined template path \"" + answers.type + "\"");
        }
        glob.sync(templatePath.path)
            .filter(function (filepath) {
            return fs.lstatSync(filepath).isFile();
        })
            .forEach(function (filepath) {
            var file = fs.readFileSync(filepath);
            var content = handlebars_1.Handlebars.compile(file.toString());
            var filename = handlebars_1.Handlebars.compile(path.basename(filepath, '.hbs'));
            var outputPath = path.join(process.cwd(), config.app.root, templatePath.output, answers.dir, filename(answers));
            console.log(chalk_1.default.green('[ADD]'), path.relative(process.cwd(), outputPath));
            fs.outputFileSync(outputPath, content(answers));
        });
    });
}
exports.generate = generate;
