'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs-extra");
var path = require("path");
var chalk_1 = require("chalk");
var assign = require("deep-assign");
var handlebars_1 = require("../handlebars/handlebars");
var glob = require("glob");
var inquirer = require("inquirer");
var spawn = require('cross-spawn');
function generateConfigure() {
    return inquirer.prompt([{
            type: 'input',
            name: 'name',
            message: 'Input your project name',
            validate: function (answer) {
                return (!!answer);
            }
        }, {
            type: 'list',
            name: 'scriptType',
            message: 'choose js file type',
            choices: [
                'js',
                'ts'
            ]
        }]);
}
exports.generateConfigure = generateConfigure;
function init(config, option) {
    generateConfigure().then(function (answers) {
        var templatePath = option.path || path.join(__dirname, "../templates/project/**/*");
        glob.sync(templatePath, { dot: true })
            .filter(function (filepath) {
            return fs.lstatSync(filepath).isFile();
        })
            .forEach(function (filepath) {
            var params = assign({ package: config.package }, answers);
            var file = fs.readFileSync(filepath);
            var content = handlebars_1.Handlebars.compile(file.toString());
            var filename = handlebars_1.Handlebars.compile(path.basename(filepath, '.hbs'));
            var relPath = path.dirname(path.relative(path.join(__dirname, '../templates/project'), filepath));
            var outputPath = path.join(process.cwd(), answers.name, relPath, filename(params));
            console.log(chalk_1.default.green('[ADD]'), path.relative(process.cwd(), outputPath));
            fs.outputFileSync(outputPath, content(params));
        });
        if (!option.skipInstall) {
            return spawn('npm', ['install'], {
                cwd: path.join(process.cwd(), answers.name),
                stdio: 'inherit'
            }).on('exit', function (code) {
                process.exit(code);
            });
        }
    });
}
exports.init = init;
