'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var glob = require("glob");
var assign = require("deep-assign");
var karma_1 = require("karma");
var index_1 = require("../webpack/index");
function generateConfigure(config, option) {
    var externalConf = assign({}, config.test);
    if (option.confFile) {
        externalConf = require(path.resolve(process.cwd(), option.confFile));
    }
    var conf = index_1.generateConfigure(config, option);
    delete conf.entry;
    delete conf.plugins;
    delete conf.output;
    var plugins = config.test.plugins || [
        require('karma-jasmine'),
        require('karma-chrome-launcher'),
        require('karma-webpack')
    ];
    var karmaConf = assign({
        basePath: path.join(process.cwd(), config.app.root),
        frameworks: ['jasmine'],
        files: config.test.files,
        exclude: config.test.exclude || [],
        preprocessors: (_a = {},
            _a["**/*." + config.app.scriptType] = ['webpack'],
            _a),
        webpack: conf,
        webpackMiddleware: {
            stats: option.verbose ? 'verbose' : 'errors-only'
        },
        mime: {
            'text/x-typescript': ['ts', 'tsx']
        },
        reporters: ['progress'],
        port: option.port,
        colors: true,
        logLevel: option.verbose ? 'DEBUG' : 'WARN',
        autoWatch: option.watch,
        browsers: ['Chrome'],
        singleRun: !option.watch,
        concurrency: Infinity,
        plugins: plugins
    }, externalConf);
    if (option.files) {
        karmaConf.files = option.files.map(function (pattern) {
            return glob.sync(pattern, {
                nodir: true,
                cwd: path.join(process.cwd(), config.app.root)
            });
        }).reduce(function (prev, currentValue) {
            return prev.concat(currentValue);
        }, []);
    }
    return karmaConf;
    var _a;
}
exports.generateConfigure = generateConfigure;
function test(config, option) {
    var karmaConf = generateConfigure(config, option);
    var server = new karma_1.Server(karmaConf, function (exitCode) {
        process.exit(exitCode);
    });
    server.start();
}
exports.test = test;
