/// <reference types="karma" />
/// <reference types="html-webpack-plugin" />
import { ConfigOptions } from 'karma';
import { Options } from 'html-webpack-plugin';
export interface Config {
    app: ConfigApp;
    test?: ConfigOptions;
    package?: any;
    generate?: ConfigGenerate;
}
export interface ConfigGenerate {
    types?: string[];
    templates?: {
        [key: string]: ConfigGenerateTemplate;
    };
}
export interface ConfigGenerateTemplate {
    path: string;
    output: string;
}
export interface GlobAsset {
    glob: string;
    input: string;
    output: string;
}
export interface ConfigPage {
    template: string;
    include?: string[];
    exclude?: string[];
    extention?: string;
    options?: Options;
    params?: any;
}
export interface UglifyOptions {
    compress?: boolean | {};
    mangle?: boolean | {};
    beautify?: boolean;
    output?: any;
    comments?: boolean | RegExp | Function;
    extractComments?: boolean | RegExp | Function | {};
    sourceMap?: boolean;
    test?: RegExp | RegExp[];
    include?: RegExp | RegExp[];
    exclude?: RegExp | RegExp[];
    warningsFilter?(source: any): boolean;
}
export interface ConfigApp {
    root: string;
    outDir: string;
    assets?: (string | GlobAsset)[];
    pages: ConfigPage[];
    vendor: string[];
    entry: Entry;
    stylePreprocessorOptions?: {
        includePaths?: string[];
    };
    scriptPreprocessorOptions?: {
        uglify?: UglifyOptions;
    };
    browsers?: string[];
    environments: {
        dev: string;
        prod: string;
        [key: string]: string;
    };
    watchIgnore?: string[];
    scriptType?: 'js' | 'ts';
    styleType?: 'css' | 'scss';
}
export interface Entry {
    [key: string]: string | string[];
}
