'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var glob = require("glob");
var assign = require("deep-assign");
var htmlhint_plugin_1 = require("./plugins/htmlhint-plugin");
var ejs_plugin_1 = require("./plugins/ejs-plugin");
var HtmlWebpackPlugin = require('html-webpack-plugin');
var entryPoints = ['vendor', 'styles', 'main'];
var chunkSort = function (left, right) {
    var leftIndex = entryPoints.indexOf(left.names[0]);
    var rightindex = entryPoints.indexOf(right.names[0]);
    if (leftIndex > rightindex) {
        return 1;
    }
    else if (leftIndex < rightindex) {
        return -1;
    }
    else {
        return 0;
    }
};
function htmlConf(config, option) {
    var htmlWebpackPlugins = [];
    var BASE_PATH = path.join(process.cwd(), config.app.root);
    config.app.pages.forEach(function (conf) {
        var templates = glob.sync(conf.template, {
            cwd: BASE_PATH
        });
        conf.extention = conf.extention || 'html';
        conf.options.chunksSortMode = chunkSort;
        if (conf.include) {
            conf.options.chunks = conf.include;
            if (conf.options.chunks.indexOf('vendor') !== -1) {
                conf.options.chunks.unshift('vendor');
            }
        }
        if (conf.exclude) {
            conf.options.excludeChunks = conf.exclude;
        }
        templates.forEach(function (filepath) {
            var op = assign({
                template: filepath,
                filename: path.relative(process.cwd(), filepath.replace('.ejs', "." + conf.extention)),
            }, conf.options);
            htmlWebpackPlugins.push(new HtmlWebpackPlugin(op));
        });
    });
    return {
        module: {
            rules: [
                {
                    test: /\.html$/,
                    use: [{
                            loader: 'raw-loader'
                        }]
                }
            ]
        },
        plugins: [
            new htmlhint_plugin_1.HtmlhintPlugin(config)
        ].concat(htmlWebpackPlugins, [
            new ejs_plugin_1.EjsPlugin(config)
        ])
    };
}
exports.htmlConf = htmlConf;
