"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var chalk_1 = require("chalk");
var assign = require("deep-assign");
var htmlhint_1 = require("htmlhint");
var DEFAULT_RULES = {
    "tagname-lowercase": true,
    "attr-lowercase": false,
    "attr-value-double-quotes": true,
    "attr-value-not-empty": false,
    "attr-no-duplication": true,
    "doctype-first": false,
    "tag-pair": true,
    "tag-self-close": false,
    "spec-char-escape": true,
    "id-unique": true,
    "src-not-empty": true,
    "head-script-disabled": false,
    "img-alt-require": true,
    "doctype-html5": true,
    "id-class-value": false,
    "style-disabled": false,
    "space-tab-mixed-disabled": true,
    "id-class-ad-disabled": true,
    "href-abs-or-rel": false,
    "attr-unsafe-chars": true
};
var HtmlhintPlugin = /** @class */ (function () {
    function HtmlhintPlugin(config) {
        this.config = config;
    }
    HtmlhintPlugin.prototype.apply = function (compiler) {
        var confFilePath = path.join(process.cwd(), '.htmlhintrc');
        var externalRules = fs.existsSync(confFilePath) ? JSON.parse(fs.readFileSync(confFilePath).toString('utf-8')) : {};
        var rules = assign({}, DEFAULT_RULES, externalRules);
        compiler.plugin('compilation', function (compilation) {
            compilation.plugin('html-webpack-plugin-after-html-processing', function (htmlPluginData, callback) {
                var result = htmlhint_1.HTMLHint.verify(htmlPluginData.html, rules);
                if (result.length !== 0) {
                    var errorCount = result.length + 1;
                    console.log(chalk_1.default.bold.red("\n" + errorCount + " errors found in " + htmlPluginData.outputName));
                    result.forEach(function (message) {
                        console.log("  - " + chalk_1.default.bold.red("[L" + message.line + ":C" + message.col + "]") + " " + chalk_1.default.yellow(message.message) + " (" + message.rule.id + ")\n");
                    });
                    compilation.errors.push(new Error('HTMLHint'));
                }
                callback(null, htmlPluginData);
            });
        });
    };
    return HtmlhintPlugin;
}());
exports.HtmlhintPlugin = HtmlhintPlugin;
