'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var ExtractTextPlugin = require('extract-text-webpack-plugin');
var StyleLintPlugin = require('stylelint-webpack-plugin');
function sassConf(config, option) {
    var extractSass = new ExtractTextPlugin({
        filename: 'assets/css/[name].bundle.css',
        disable: !option.extractCss
    });
    var postCssPlugins = [
        require('autoprefixer')(config.app.browsers)
    ];
    if (option.production) {
        postCssPlugins.push(require('postcss-csso')());
    }
    return {
        module: {
            rules: [{
                    test: /\.scss$/,
                    use: [{
                            loader: 'cache-loader',
                            options: {
                                cacheDirectory: path.join(process.cwd(), '.cache/css')
                            }
                        }].concat(extractSass.extract({
                        use: [{
                                loader: 'css-loader',
                                options: {
                                    sourceMap: false,
                                    importLoaders: 1
                                }
                            }, {
                                loader: 'postcss-loader',
                                options: {
                                    plugins: postCssPlugins,
                                    config: {
                                        path: path.resolve(process.cwd(), 'postcss.config.js')
                                    }
                                }
                            }, {
                                loader: 'sass-loader',
                                options: config.app.stylePreprocessorOptions
                            }],
                        // use style-loader in development
                        fallback: 'style-loader',
                        publicPath: 'assets/css'
                    }))
                }]
        },
        plugins: [
            extractSass,
            new StyleLintPlugin({
                syntax: 'scss',
                emitErrors: false
            })
        ]
    };
}
exports.sassConf = sassConf;
